@@ -19,13 +19,11 @@ async def get_a_resp_text_async(url ,
                                 verify_ssl ,
                                 timeout) :
     async with ClientSession(trust_env = trust_env) as ses :
-        async with ses.get(
-                url ,
+        async with ses.get(url ,
                 params = params ,
                 headers = headers ,
                 verify_ssl = verify_ssl ,
-                timeout = timeout
-                ) as resp :
+                timeout = timeout) as resp :
             if resp.status == 200 :
                 return await resp.text()
 
@@ -35,14 +33,12 @@ async def get_reps_texts_async(urls ,
                                headers = None ,
                                verify_ssl = True ,
                                timeout = None) :
-    fu = partial(
-            get_a_resp_text_async ,
+    fu = partial(get_a_resp_text_async ,
             trust_env = trust_env ,
             params = params ,
             headers = headers ,
             verify_ssl = verify_ssl ,
-            timeout = timeout
-            )
+            timeout = timeout)
     co_tasks = [fu(x) for x in urls]
     return await asyncio.gather(*co_tasks)
 
@@ -54,9 +50,9 @@ async def get_a_resp_json_async(url ,
                                 verify_ssl ,
                                 content_type) :
     async with ClientSession(trust_env = trust_env) as ses :
-        async with ses.get(
-                url , params = params , verify_ssl = verify_ssl
-                ) as resp :
+        async with ses.get(url ,
+                params = params ,
+                verify_ssl = verify_ssl) as resp :
             if resp.status == 200 :
                 return await resp.json(content_type = content_type)
 
@@ -65,13 +61,11 @@ async def get_reps_jsons_async(urls ,
                                params = None ,
                                verify_ssl = True ,
                                content_type = None) :
-    fu = partial(
-            get_a_resp_json_async ,
+    fu = partial(get_a_resp_json_async ,
             trust_env = trust_env ,
             params = params ,
             verify_ssl = verify_ssl ,
-            content_type = content_type
-            )
+            content_type = content_type)
 
     co_tasks = [fu(x) for x in urls]
 
